@@ -51,20 +51,20 @@ __all__ = (
     "AnalyzedResourceSummaryTypeDef",
     "AnalyzedResourceTypeDef",
     "AnalyzerSummaryTypeDef",
-    "ApplyArchiveRuleRequestTypeDef",
+    "ApplyArchiveRuleRequestRequestTypeDef",
     "ArchiveRuleSummaryTypeDef",
-    "CancelPolicyGenerationRequestTypeDef",
+    "CancelPolicyGenerationRequestRequestTypeDef",
     "CloudTrailDetailsTypeDef",
     "CloudTrailPropertiesTypeDef",
     "ConfigurationTypeDef",
-    "CreateAccessPreviewRequestTypeDef",
-    "CreateAccessPreviewResponseResponseTypeDef",
-    "CreateAnalyzerRequestTypeDef",
-    "CreateAnalyzerResponseResponseTypeDef",
-    "CreateArchiveRuleRequestTypeDef",
+    "CreateAccessPreviewRequestRequestTypeDef",
+    "CreateAccessPreviewResponseTypeDef",
+    "CreateAnalyzerRequestRequestTypeDef",
+    "CreateAnalyzerResponseTypeDef",
+    "CreateArchiveRuleRequestRequestTypeDef",
     "CriterionTypeDef",
-    "DeleteAnalyzerRequestTypeDef",
-    "DeleteArchiveRuleRequestTypeDef",
+    "DeleteAnalyzerRequestRequestTypeDef",
+    "DeleteArchiveRuleRequestRequestTypeDef",
     "FindingSourceDetailTypeDef",
     "FindingSourceTypeDef",
     "FindingSummaryTypeDef",
@@ -72,18 +72,18 @@ __all__ = (
     "GeneratedPolicyPropertiesTypeDef",
     "GeneratedPolicyResultTypeDef",
     "GeneratedPolicyTypeDef",
-    "GetAccessPreviewRequestTypeDef",
-    "GetAccessPreviewResponseResponseTypeDef",
-    "GetAnalyzedResourceRequestTypeDef",
-    "GetAnalyzedResourceResponseResponseTypeDef",
-    "GetAnalyzerRequestTypeDef",
-    "GetAnalyzerResponseResponseTypeDef",
-    "GetArchiveRuleRequestTypeDef",
-    "GetArchiveRuleResponseResponseTypeDef",
-    "GetFindingRequestTypeDef",
-    "GetFindingResponseResponseTypeDef",
-    "GetGeneratedPolicyRequestTypeDef",
-    "GetGeneratedPolicyResponseResponseTypeDef",
+    "GetAccessPreviewRequestRequestTypeDef",
+    "GetAccessPreviewResponseTypeDef",
+    "GetAnalyzedResourceRequestRequestTypeDef",
+    "GetAnalyzedResourceResponseTypeDef",
+    "GetAnalyzerRequestRequestTypeDef",
+    "GetAnalyzerResponseTypeDef",
+    "GetArchiveRuleRequestRequestTypeDef",
+    "GetArchiveRuleResponseTypeDef",
+    "GetFindingRequestRequestTypeDef",
+    "GetFindingResponseTypeDef",
+    "GetGeneratedPolicyRequestRequestTypeDef",
+    "GetGeneratedPolicyResponseTypeDef",
     "IamRoleConfigurationTypeDef",
     "InlineArchiveRuleTypeDef",
     "JobDetailsTypeDef",
@@ -91,22 +91,22 @@ __all__ = (
     "KmsGrantConfigurationTypeDef",
     "KmsGrantConstraintsTypeDef",
     "KmsKeyConfigurationTypeDef",
-    "ListAccessPreviewFindingsRequestTypeDef",
-    "ListAccessPreviewFindingsResponseResponseTypeDef",
-    "ListAccessPreviewsRequestTypeDef",
-    "ListAccessPreviewsResponseResponseTypeDef",
-    "ListAnalyzedResourcesRequestTypeDef",
-    "ListAnalyzedResourcesResponseResponseTypeDef",
-    "ListAnalyzersRequestTypeDef",
-    "ListAnalyzersResponseResponseTypeDef",
-    "ListArchiveRulesRequestTypeDef",
-    "ListArchiveRulesResponseResponseTypeDef",
-    "ListFindingsRequestTypeDef",
-    "ListFindingsResponseResponseTypeDef",
-    "ListPolicyGenerationsRequestTypeDef",
-    "ListPolicyGenerationsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "ListAccessPreviewFindingsRequestRequestTypeDef",
+    "ListAccessPreviewFindingsResponseTypeDef",
+    "ListAccessPreviewsRequestRequestTypeDef",
+    "ListAccessPreviewsResponseTypeDef",
+    "ListAnalyzedResourcesRequestRequestTypeDef",
+    "ListAnalyzedResourcesResponseTypeDef",
+    "ListAnalyzersRequestRequestTypeDef",
+    "ListAnalyzersResponseTypeDef",
+    "ListArchiveRulesRequestRequestTypeDef",
+    "ListArchiveRulesResponseTypeDef",
+    "ListFindingsRequestRequestTypeDef",
+    "ListFindingsResponseTypeDef",
+    "ListPolicyGenerationsRequestRequestTypeDef",
+    "ListPolicyGenerationsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "LocationTypeDef",
     "NetworkOriginConfigurationTypeDef",
     "PaginatorConfigTypeDef",
@@ -123,20 +123,20 @@ __all__ = (
     "SortCriteriaTypeDef",
     "SpanTypeDef",
     "SqsQueueConfigurationTypeDef",
-    "StartPolicyGenerationRequestTypeDef",
-    "StartPolicyGenerationResponseResponseTypeDef",
-    "StartResourceScanRequestTypeDef",
+    "StartPolicyGenerationRequestRequestTypeDef",
+    "StartPolicyGenerationResponseTypeDef",
+    "StartResourceScanRequestRequestTypeDef",
     "StatusReasonTypeDef",
     "SubstringTypeDef",
-    "TagResourceRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TrailPropertiesTypeDef",
     "TrailTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateArchiveRuleRequestTypeDef",
-    "UpdateFindingsRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateArchiveRuleRequestRequestTypeDef",
+    "UpdateFindingsRequestRequestTypeDef",
     "ValidatePolicyFindingTypeDef",
-    "ValidatePolicyRequestTypeDef",
-    "ValidatePolicyResponseResponseTypeDef",
+    "ValidatePolicyRequestRequestTypeDef",
+    "ValidatePolicyResponseTypeDef",
     "VpcConfigurationTypeDef",
 )
 
@@ -300,15 +300,15 @@ class AnalyzerSummaryTypeDef(_RequiredAnalyzerSummaryTypeDef, _OptionalAnalyzerS
     pass
 
 
-_RequiredApplyArchiveRuleRequestTypeDef = TypedDict(
-    "_RequiredApplyArchiveRuleRequestTypeDef",
+_RequiredApplyArchiveRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredApplyArchiveRuleRequestRequestTypeDef",
     {
         "analyzerArn": str,
         "ruleName": str,
     },
 )
-_OptionalApplyArchiveRuleRequestTypeDef = TypedDict(
-    "_OptionalApplyArchiveRuleRequestTypeDef",
+_OptionalApplyArchiveRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalApplyArchiveRuleRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -316,8 +316,8 @@ _OptionalApplyArchiveRuleRequestTypeDef = TypedDict(
 )
 
 
-class ApplyArchiveRuleRequestTypeDef(
-    _RequiredApplyArchiveRuleRequestTypeDef, _OptionalApplyArchiveRuleRequestTypeDef
+class ApplyArchiveRuleRequestRequestTypeDef(
+    _RequiredApplyArchiveRuleRequestRequestTypeDef, _OptionalApplyArchiveRuleRequestRequestTypeDef
 ):
     pass
 
@@ -332,8 +332,8 @@ ArchiveRuleSummaryTypeDef = TypedDict(
     },
 )
 
-CancelPolicyGenerationRequestTypeDef = TypedDict(
-    "CancelPolicyGenerationRequestTypeDef",
+CancelPolicyGenerationRequestRequestTypeDef = TypedDict(
+    "CancelPolicyGenerationRequestRequestTypeDef",
     {
         "jobId": str,
     },
@@ -383,15 +383,15 @@ ConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCreateAccessPreviewRequestTypeDef = TypedDict(
-    "_RequiredCreateAccessPreviewRequestTypeDef",
+_RequiredCreateAccessPreviewRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAccessPreviewRequestRequestTypeDef",
     {
         "analyzerArn": str,
         "configurations": Dict[str, "ConfigurationTypeDef"],
     },
 )
-_OptionalCreateAccessPreviewRequestTypeDef = TypedDict(
-    "_OptionalCreateAccessPreviewRequestTypeDef",
+_OptionalCreateAccessPreviewRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAccessPreviewRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -399,29 +399,30 @@ _OptionalCreateAccessPreviewRequestTypeDef = TypedDict(
 )
 
 
-class CreateAccessPreviewRequestTypeDef(
-    _RequiredCreateAccessPreviewRequestTypeDef, _OptionalCreateAccessPreviewRequestTypeDef
+class CreateAccessPreviewRequestRequestTypeDef(
+    _RequiredCreateAccessPreviewRequestRequestTypeDef,
+    _OptionalCreateAccessPreviewRequestRequestTypeDef,
 ):
     pass
 
 
-CreateAccessPreviewResponseResponseTypeDef = TypedDict(
-    "CreateAccessPreviewResponseResponseTypeDef",
+CreateAccessPreviewResponseTypeDef = TypedDict(
+    "CreateAccessPreviewResponseTypeDef",
     {
         "id": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateAnalyzerRequestTypeDef = TypedDict(
-    "_RequiredCreateAnalyzerRequestTypeDef",
+_RequiredCreateAnalyzerRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAnalyzerRequestRequestTypeDef",
     {
         "analyzerName": str,
         "type": TypeType,
     },
 )
-_OptionalCreateAnalyzerRequestTypeDef = TypedDict(
-    "_OptionalCreateAnalyzerRequestTypeDef",
+_OptionalCreateAnalyzerRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAnalyzerRequestRequestTypeDef",
     {
         "archiveRules": List["InlineArchiveRuleTypeDef"],
         "clientToken": str,
@@ -431,30 +432,30 @@ _OptionalCreateAnalyzerRequestTypeDef = TypedDict(
 )
 
 
-class CreateAnalyzerRequestTypeDef(
-    _RequiredCreateAnalyzerRequestTypeDef, _OptionalCreateAnalyzerRequestTypeDef
+class CreateAnalyzerRequestRequestTypeDef(
+    _RequiredCreateAnalyzerRequestRequestTypeDef, _OptionalCreateAnalyzerRequestRequestTypeDef
 ):
     pass
 
 
-CreateAnalyzerResponseResponseTypeDef = TypedDict(
-    "CreateAnalyzerResponseResponseTypeDef",
+CreateAnalyzerResponseTypeDef = TypedDict(
+    "CreateAnalyzerResponseTypeDef",
     {
         "arn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateArchiveRuleRequestTypeDef = TypedDict(
-    "_RequiredCreateArchiveRuleRequestTypeDef",
+_RequiredCreateArchiveRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateArchiveRuleRequestRequestTypeDef",
     {
         "analyzerName": str,
         "filter": Dict[str, "CriterionTypeDef"],
         "ruleName": str,
     },
 )
-_OptionalCreateArchiveRuleRequestTypeDef = TypedDict(
-    "_OptionalCreateArchiveRuleRequestTypeDef",
+_OptionalCreateArchiveRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateArchiveRuleRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -462,8 +463,8 @@ _OptionalCreateArchiveRuleRequestTypeDef = TypedDict(
 )
 
 
-class CreateArchiveRuleRequestTypeDef(
-    _RequiredCreateArchiveRuleRequestTypeDef, _OptionalCreateArchiveRuleRequestTypeDef
+class CreateArchiveRuleRequestRequestTypeDef(
+    _RequiredCreateArchiveRuleRequestRequestTypeDef, _OptionalCreateArchiveRuleRequestRequestTypeDef
 ):
     pass
 
@@ -479,14 +480,14 @@ CriterionTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredDeleteAnalyzerRequestTypeDef = TypedDict(
-    "_RequiredDeleteAnalyzerRequestTypeDef",
+_RequiredDeleteAnalyzerRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteAnalyzerRequestRequestTypeDef",
     {
         "analyzerName": str,
     },
 )
-_OptionalDeleteAnalyzerRequestTypeDef = TypedDict(
-    "_OptionalDeleteAnalyzerRequestTypeDef",
+_OptionalDeleteAnalyzerRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteAnalyzerRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -494,21 +495,21 @@ _OptionalDeleteAnalyzerRequestTypeDef = TypedDict(
 )
 
 
-class DeleteAnalyzerRequestTypeDef(
-    _RequiredDeleteAnalyzerRequestTypeDef, _OptionalDeleteAnalyzerRequestTypeDef
+class DeleteAnalyzerRequestRequestTypeDef(
+    _RequiredDeleteAnalyzerRequestRequestTypeDef, _OptionalDeleteAnalyzerRequestRequestTypeDef
 ):
     pass
 
 
-_RequiredDeleteArchiveRuleRequestTypeDef = TypedDict(
-    "_RequiredDeleteArchiveRuleRequestTypeDef",
+_RequiredDeleteArchiveRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteArchiveRuleRequestRequestTypeDef",
     {
         "analyzerName": str,
         "ruleName": str,
     },
 )
-_OptionalDeleteArchiveRuleRequestTypeDef = TypedDict(
-    "_OptionalDeleteArchiveRuleRequestTypeDef",
+_OptionalDeleteArchiveRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteArchiveRuleRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -516,8 +517,8 @@ _OptionalDeleteArchiveRuleRequestTypeDef = TypedDict(
 )
 
 
-class DeleteArchiveRuleRequestTypeDef(
-    _RequiredDeleteArchiveRuleRequestTypeDef, _OptionalDeleteArchiveRuleRequestTypeDef
+class DeleteArchiveRuleRequestRequestTypeDef(
+    _RequiredDeleteArchiveRuleRequestRequestTypeDef, _OptionalDeleteArchiveRuleRequestRequestTypeDef
 ):
     pass
 
@@ -661,93 +662,93 @@ GeneratedPolicyTypeDef = TypedDict(
     },
 )
 
-GetAccessPreviewRequestTypeDef = TypedDict(
-    "GetAccessPreviewRequestTypeDef",
+GetAccessPreviewRequestRequestTypeDef = TypedDict(
+    "GetAccessPreviewRequestRequestTypeDef",
     {
         "accessPreviewId": str,
         "analyzerArn": str,
     },
 )
 
-GetAccessPreviewResponseResponseTypeDef = TypedDict(
-    "GetAccessPreviewResponseResponseTypeDef",
+GetAccessPreviewResponseTypeDef = TypedDict(
+    "GetAccessPreviewResponseTypeDef",
     {
         "accessPreview": "AccessPreviewTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetAnalyzedResourceRequestTypeDef = TypedDict(
-    "GetAnalyzedResourceRequestTypeDef",
+GetAnalyzedResourceRequestRequestTypeDef = TypedDict(
+    "GetAnalyzedResourceRequestRequestTypeDef",
     {
         "analyzerArn": str,
         "resourceArn": str,
     },
 )
 
-GetAnalyzedResourceResponseResponseTypeDef = TypedDict(
-    "GetAnalyzedResourceResponseResponseTypeDef",
+GetAnalyzedResourceResponseTypeDef = TypedDict(
+    "GetAnalyzedResourceResponseTypeDef",
     {
         "resource": "AnalyzedResourceTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetAnalyzerRequestTypeDef = TypedDict(
-    "GetAnalyzerRequestTypeDef",
+GetAnalyzerRequestRequestTypeDef = TypedDict(
+    "GetAnalyzerRequestRequestTypeDef",
     {
         "analyzerName": str,
     },
 )
 
-GetAnalyzerResponseResponseTypeDef = TypedDict(
-    "GetAnalyzerResponseResponseTypeDef",
+GetAnalyzerResponseTypeDef = TypedDict(
+    "GetAnalyzerResponseTypeDef",
     {
         "analyzer": "AnalyzerSummaryTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetArchiveRuleRequestTypeDef = TypedDict(
-    "GetArchiveRuleRequestTypeDef",
+GetArchiveRuleRequestRequestTypeDef = TypedDict(
+    "GetArchiveRuleRequestRequestTypeDef",
     {
         "analyzerName": str,
         "ruleName": str,
     },
 )
 
-GetArchiveRuleResponseResponseTypeDef = TypedDict(
-    "GetArchiveRuleResponseResponseTypeDef",
+GetArchiveRuleResponseTypeDef = TypedDict(
+    "GetArchiveRuleResponseTypeDef",
     {
         "archiveRule": "ArchiveRuleSummaryTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetFindingRequestTypeDef = TypedDict(
-    "GetFindingRequestTypeDef",
+GetFindingRequestRequestTypeDef = TypedDict(
+    "GetFindingRequestRequestTypeDef",
     {
         "analyzerArn": str,
         "id": str,
     },
 )
 
-GetFindingResponseResponseTypeDef = TypedDict(
-    "GetFindingResponseResponseTypeDef",
+GetFindingResponseTypeDef = TypedDict(
+    "GetFindingResponseTypeDef",
     {
         "finding": "FindingTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredGetGeneratedPolicyRequestTypeDef = TypedDict(
-    "_RequiredGetGeneratedPolicyRequestTypeDef",
+_RequiredGetGeneratedPolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredGetGeneratedPolicyRequestRequestTypeDef",
     {
         "jobId": str,
     },
 )
-_OptionalGetGeneratedPolicyRequestTypeDef = TypedDict(
-    "_OptionalGetGeneratedPolicyRequestTypeDef",
+_OptionalGetGeneratedPolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalGetGeneratedPolicyRequestRequestTypeDef",
     {
         "includeResourcePlaceholders": bool,
         "includeServiceLevelTemplate": bool,
@@ -756,14 +757,15 @@ _OptionalGetGeneratedPolicyRequestTypeDef = TypedDict(
 )
 
 
-class GetGeneratedPolicyRequestTypeDef(
-    _RequiredGetGeneratedPolicyRequestTypeDef, _OptionalGetGeneratedPolicyRequestTypeDef
+class GetGeneratedPolicyRequestRequestTypeDef(
+    _RequiredGetGeneratedPolicyRequestRequestTypeDef,
+    _OptionalGetGeneratedPolicyRequestRequestTypeDef,
 ):
     pass
 
 
-GetGeneratedPolicyResponseResponseTypeDef = TypedDict(
-    "GetGeneratedPolicyResponseResponseTypeDef",
+GetGeneratedPolicyResponseTypeDef = TypedDict(
+    "GetGeneratedPolicyResponseTypeDef",
     {
         "generatedPolicyResult": "GeneratedPolicyResultTypeDef",
         "jobDetails": "JobDetailsTypeDef",
@@ -859,15 +861,15 @@ KmsKeyConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListAccessPreviewFindingsRequestTypeDef = TypedDict(
-    "_RequiredListAccessPreviewFindingsRequestTypeDef",
+_RequiredListAccessPreviewFindingsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAccessPreviewFindingsRequestRequestTypeDef",
     {
         "accessPreviewId": str,
         "analyzerArn": str,
     },
 )
-_OptionalListAccessPreviewFindingsRequestTypeDef = TypedDict(
-    "_OptionalListAccessPreviewFindingsRequestTypeDef",
+_OptionalListAccessPreviewFindingsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAccessPreviewFindingsRequestRequestTypeDef",
     {
         "filter": Dict[str, "CriterionTypeDef"],
         "maxResults": int,
@@ -877,15 +879,15 @@ _OptionalListAccessPreviewFindingsRequestTypeDef = TypedDict(
 )
 
 
-class ListAccessPreviewFindingsRequestTypeDef(
-    _RequiredListAccessPreviewFindingsRequestTypeDef,
-    _OptionalListAccessPreviewFindingsRequestTypeDef,
+class ListAccessPreviewFindingsRequestRequestTypeDef(
+    _RequiredListAccessPreviewFindingsRequestRequestTypeDef,
+    _OptionalListAccessPreviewFindingsRequestRequestTypeDef,
 ):
     pass
 
 
-ListAccessPreviewFindingsResponseResponseTypeDef = TypedDict(
-    "ListAccessPreviewFindingsResponseResponseTypeDef",
+ListAccessPreviewFindingsResponseTypeDef = TypedDict(
+    "ListAccessPreviewFindingsResponseTypeDef",
     {
         "findings": List["AccessPreviewFindingTypeDef"],
         "nextToken": str,
@@ -893,14 +895,14 @@ ListAccessPreviewFindingsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListAccessPreviewsRequestTypeDef = TypedDict(
-    "_RequiredListAccessPreviewsRequestTypeDef",
+_RequiredListAccessPreviewsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAccessPreviewsRequestRequestTypeDef",
     {
         "analyzerArn": str,
     },
 )
-_OptionalListAccessPreviewsRequestTypeDef = TypedDict(
-    "_OptionalListAccessPreviewsRequestTypeDef",
+_OptionalListAccessPreviewsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAccessPreviewsRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -909,14 +911,15 @@ _OptionalListAccessPreviewsRequestTypeDef = TypedDict(
 )
 
 
-class ListAccessPreviewsRequestTypeDef(
-    _RequiredListAccessPreviewsRequestTypeDef, _OptionalListAccessPreviewsRequestTypeDef
+class ListAccessPreviewsRequestRequestTypeDef(
+    _RequiredListAccessPreviewsRequestRequestTypeDef,
+    _OptionalListAccessPreviewsRequestRequestTypeDef,
 ):
     pass
 
 
-ListAccessPreviewsResponseResponseTypeDef = TypedDict(
-    "ListAccessPreviewsResponseResponseTypeDef",
+ListAccessPreviewsResponseTypeDef = TypedDict(
+    "ListAccessPreviewsResponseTypeDef",
     {
         "accessPreviews": List["AccessPreviewSummaryTypeDef"],
         "nextToken": str,
@@ -924,14 +927,14 @@ ListAccessPreviewsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListAnalyzedResourcesRequestTypeDef = TypedDict(
-    "_RequiredListAnalyzedResourcesRequestTypeDef",
+_RequiredListAnalyzedResourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListAnalyzedResourcesRequestRequestTypeDef",
     {
         "analyzerArn": str,
     },
 )
-_OptionalListAnalyzedResourcesRequestTypeDef = TypedDict(
-    "_OptionalListAnalyzedResourcesRequestTypeDef",
+_OptionalListAnalyzedResourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListAnalyzedResourcesRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -941,14 +944,15 @@ _OptionalListAnalyzedResourcesRequestTypeDef = TypedDict(
 )
 
 
-class ListAnalyzedResourcesRequestTypeDef(
-    _RequiredListAnalyzedResourcesRequestTypeDef, _OptionalListAnalyzedResourcesRequestTypeDef
+class ListAnalyzedResourcesRequestRequestTypeDef(
+    _RequiredListAnalyzedResourcesRequestRequestTypeDef,
+    _OptionalListAnalyzedResourcesRequestRequestTypeDef,
 ):
     pass
 
 
-ListAnalyzedResourcesResponseResponseTypeDef = TypedDict(
-    "ListAnalyzedResourcesResponseResponseTypeDef",
+ListAnalyzedResourcesResponseTypeDef = TypedDict(
+    "ListAnalyzedResourcesResponseTypeDef",
     {
         "analyzedResources": List["AnalyzedResourceSummaryTypeDef"],
         "nextToken": str,
@@ -956,8 +960,8 @@ ListAnalyzedResourcesResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListAnalyzersRequestTypeDef = TypedDict(
-    "ListAnalyzersRequestTypeDef",
+ListAnalyzersRequestRequestTypeDef = TypedDict(
+    "ListAnalyzersRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -966,8 +970,8 @@ ListAnalyzersRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListAnalyzersResponseResponseTypeDef = TypedDict(
-    "ListAnalyzersResponseResponseTypeDef",
+ListAnalyzersResponseTypeDef = TypedDict(
+    "ListAnalyzersResponseTypeDef",
     {
         "analyzers": List["AnalyzerSummaryTypeDef"],
         "nextToken": str,
@@ -975,14 +979,14 @@ ListAnalyzersResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListArchiveRulesRequestTypeDef = TypedDict(
-    "_RequiredListArchiveRulesRequestTypeDef",
+_RequiredListArchiveRulesRequestRequestTypeDef = TypedDict(
+    "_RequiredListArchiveRulesRequestRequestTypeDef",
     {
         "analyzerName": str,
     },
 )
-_OptionalListArchiveRulesRequestTypeDef = TypedDict(
-    "_OptionalListArchiveRulesRequestTypeDef",
+_OptionalListArchiveRulesRequestRequestTypeDef = TypedDict(
+    "_OptionalListArchiveRulesRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -991,14 +995,14 @@ _OptionalListArchiveRulesRequestTypeDef = TypedDict(
 )
 
 
-class ListArchiveRulesRequestTypeDef(
-    _RequiredListArchiveRulesRequestTypeDef, _OptionalListArchiveRulesRequestTypeDef
+class ListArchiveRulesRequestRequestTypeDef(
+    _RequiredListArchiveRulesRequestRequestTypeDef, _OptionalListArchiveRulesRequestRequestTypeDef
 ):
     pass
 
 
-ListArchiveRulesResponseResponseTypeDef = TypedDict(
-    "ListArchiveRulesResponseResponseTypeDef",
+ListArchiveRulesResponseTypeDef = TypedDict(
+    "ListArchiveRulesResponseTypeDef",
     {
         "archiveRules": List["ArchiveRuleSummaryTypeDef"],
         "nextToken": str,
@@ -1006,14 +1010,14 @@ ListArchiveRulesResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListFindingsRequestTypeDef = TypedDict(
-    "_RequiredListFindingsRequestTypeDef",
+_RequiredListFindingsRequestRequestTypeDef = TypedDict(
+    "_RequiredListFindingsRequestRequestTypeDef",
     {
         "analyzerArn": str,
     },
 )
-_OptionalListFindingsRequestTypeDef = TypedDict(
-    "_OptionalListFindingsRequestTypeDef",
+_OptionalListFindingsRequestRequestTypeDef = TypedDict(
+    "_OptionalListFindingsRequestRequestTypeDef",
     {
         "filter": Dict[str, "CriterionTypeDef"],
         "maxResults": int,
@@ -1024,14 +1028,14 @@ _OptionalListFindingsRequestTypeDef = TypedDict(
 )
 
 
-class ListFindingsRequestTypeDef(
-    _RequiredListFindingsRequestTypeDef, _OptionalListFindingsRequestTypeDef
+class ListFindingsRequestRequestTypeDef(
+    _RequiredListFindingsRequestRequestTypeDef, _OptionalListFindingsRequestRequestTypeDef
 ):
     pass
 
 
-ListFindingsResponseResponseTypeDef = TypedDict(
-    "ListFindingsResponseResponseTypeDef",
+ListFindingsResponseTypeDef = TypedDict(
+    "ListFindingsResponseTypeDef",
     {
         "findings": List["FindingSummaryTypeDef"],
         "nextToken": str,
@@ -1039,8 +1043,8 @@ ListFindingsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListPolicyGenerationsRequestTypeDef = TypedDict(
-    "ListPolicyGenerationsRequestTypeDef",
+ListPolicyGenerationsRequestRequestTypeDef = TypedDict(
+    "ListPolicyGenerationsRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -1049,8 +1053,8 @@ ListPolicyGenerationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPolicyGenerationsResponseResponseTypeDef = TypedDict(
-    "ListPolicyGenerationsResponseResponseTypeDef",
+ListPolicyGenerationsResponseTypeDef = TypedDict(
+    "ListPolicyGenerationsResponseTypeDef",
     {
         "nextToken": str,
         "policyGenerations": List["PolicyGenerationTypeDef"],
@@ -1058,15 +1062,15 @@ ListPolicyGenerationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1231,14 +1235,14 @@ SqsQueueConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredStartPolicyGenerationRequestTypeDef = TypedDict(
-    "_RequiredStartPolicyGenerationRequestTypeDef",
+_RequiredStartPolicyGenerationRequestRequestTypeDef = TypedDict(
+    "_RequiredStartPolicyGenerationRequestRequestTypeDef",
     {
         "policyGenerationDetails": "PolicyGenerationDetailsTypeDef",
     },
 )
-_OptionalStartPolicyGenerationRequestTypeDef = TypedDict(
-    "_OptionalStartPolicyGenerationRequestTypeDef",
+_OptionalStartPolicyGenerationRequestRequestTypeDef = TypedDict(
+    "_OptionalStartPolicyGenerationRequestRequestTypeDef",
     {
         "clientToken": str,
         "cloudTrailDetails": "CloudTrailDetailsTypeDef",
@@ -1247,22 +1251,23 @@ _OptionalStartPolicyGenerationRequestTypeDef = TypedDict(
 )
 
 
-class StartPolicyGenerationRequestTypeDef(
-    _RequiredStartPolicyGenerationRequestTypeDef, _OptionalStartPolicyGenerationRequestTypeDef
+class StartPolicyGenerationRequestRequestTypeDef(
+    _RequiredStartPolicyGenerationRequestRequestTypeDef,
+    _OptionalStartPolicyGenerationRequestRequestTypeDef,
 ):
     pass
 
 
-StartPolicyGenerationResponseResponseTypeDef = TypedDict(
-    "StartPolicyGenerationResponseResponseTypeDef",
+StartPolicyGenerationResponseTypeDef = TypedDict(
+    "StartPolicyGenerationResponseTypeDef",
     {
         "jobId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-StartResourceScanRequestTypeDef = TypedDict(
-    "StartResourceScanRequestTypeDef",
+StartResourceScanRequestRequestTypeDef = TypedDict(
+    "StartResourceScanRequestRequestTypeDef",
     {
         "analyzerArn": str,
         "resourceArn": str,
@@ -1284,8 +1289,8 @@ SubstringTypeDef = TypedDict(
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tags": Dict[str, str],
@@ -1332,24 +1337,24 @@ class TrailTypeDef(_RequiredTrailTypeDef, _OptionalTrailTypeDef):
     pass
 
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tagKeys": List[str],
     },
 )
 
-_RequiredUpdateArchiveRuleRequestTypeDef = TypedDict(
-    "_RequiredUpdateArchiveRuleRequestTypeDef",
+_RequiredUpdateArchiveRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateArchiveRuleRequestRequestTypeDef",
     {
         "analyzerName": str,
         "filter": Dict[str, "CriterionTypeDef"],
         "ruleName": str,
     },
 )
-_OptionalUpdateArchiveRuleRequestTypeDef = TypedDict(
-    "_OptionalUpdateArchiveRuleRequestTypeDef",
+_OptionalUpdateArchiveRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateArchiveRuleRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -1357,21 +1362,21 @@ _OptionalUpdateArchiveRuleRequestTypeDef = TypedDict(
 )
 
 
-class UpdateArchiveRuleRequestTypeDef(
-    _RequiredUpdateArchiveRuleRequestTypeDef, _OptionalUpdateArchiveRuleRequestTypeDef
+class UpdateArchiveRuleRequestRequestTypeDef(
+    _RequiredUpdateArchiveRuleRequestRequestTypeDef, _OptionalUpdateArchiveRuleRequestRequestTypeDef
 ):
     pass
 
 
-_RequiredUpdateFindingsRequestTypeDef = TypedDict(
-    "_RequiredUpdateFindingsRequestTypeDef",
+_RequiredUpdateFindingsRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateFindingsRequestRequestTypeDef",
     {
         "analyzerArn": str,
         "status": FindingStatusUpdateType,
     },
 )
-_OptionalUpdateFindingsRequestTypeDef = TypedDict(
-    "_OptionalUpdateFindingsRequestTypeDef",
+_OptionalUpdateFindingsRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateFindingsRequestRequestTypeDef",
     {
         "clientToken": str,
         "ids": List[str],
@@ -1381,8 +1386,8 @@ _OptionalUpdateFindingsRequestTypeDef = TypedDict(
 )
 
 
-class UpdateFindingsRequestTypeDef(
-    _RequiredUpdateFindingsRequestTypeDef, _OptionalUpdateFindingsRequestTypeDef
+class UpdateFindingsRequestRequestTypeDef(
+    _RequiredUpdateFindingsRequestRequestTypeDef, _OptionalUpdateFindingsRequestRequestTypeDef
 ):
     pass
 
@@ -1398,15 +1403,15 @@ ValidatePolicyFindingTypeDef = TypedDict(
     },
 )
 
-_RequiredValidatePolicyRequestTypeDef = TypedDict(
-    "_RequiredValidatePolicyRequestTypeDef",
+_RequiredValidatePolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredValidatePolicyRequestRequestTypeDef",
     {
         "policyDocument": str,
         "policyType": PolicyTypeType,
     },
 )
-_OptionalValidatePolicyRequestTypeDef = TypedDict(
-    "_OptionalValidatePolicyRequestTypeDef",
+_OptionalValidatePolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalValidatePolicyRequestRequestTypeDef",
     {
         "locale": LocaleType,
         "maxResults": int,
@@ -1416,14 +1421,14 @@ _OptionalValidatePolicyRequestTypeDef = TypedDict(
 )
 
 
-class ValidatePolicyRequestTypeDef(
-    _RequiredValidatePolicyRequestTypeDef, _OptionalValidatePolicyRequestTypeDef
+class ValidatePolicyRequestRequestTypeDef(
+    _RequiredValidatePolicyRequestRequestTypeDef, _OptionalValidatePolicyRequestRequestTypeDef
 ):
     pass
 
 
-ValidatePolicyResponseResponseTypeDef = TypedDict(
-    "ValidatePolicyResponseResponseTypeDef",
+ValidatePolicyResponseTypeDef = TypedDict(
+    "ValidatePolicyResponseTypeDef",
     {
         "findings": List["ValidatePolicyFindingTypeDef"],
         "nextToken": str,
